From: Chuck Lever <chuck.lever@oracle.com>
To: steved@redhat.com
Cc: linux-nfs@vger.kernel.org
Subject: [PATCH 08/10] mount.nfs: Teach umount.nfs to recognize netids in /etc/mtab
Date: Tue, 08 Dec 2009 13:00:34 -0500 [thread overview]
Message-ID: <20091208180033.2544.68238.stgit@localhost.localdomain> (raw)
In-Reply-To: <20091208175128.2544.457.stgit-bi+AKbBUZKY6gyzm1THtWbp2dZbC/Bob@public.gmane.org>
umount.nfs has to detect the correct address family to use when
looking up the server.
Signed-off-by: Chuck Lever <chuck.lever@oracle.com>
---
utils/mount/nfsumount.c | 15 +++++++++++----
1 files changed, 11 insertions(+), 4 deletions(-)
diff --git a/utils/mount/nfsumount.c b/utils/mount/nfsumount.c
index c5505b1..9d798a2 100644
--- a/utils/mount/nfsumount.c
+++ b/utils/mount/nfsumount.c
@@ -169,10 +169,15 @@ out:
static int nfs_umount_do_umnt(struct mount_options *options,
char **hostname, char **dirname)
{
- struct sockaddr_storage address;
- struct sockaddr *sap = (struct sockaddr *)&address;
+ union {
+ struct sockaddr sa;
+ struct sockaddr_in s4;
+ struct sockaddr_in6 s6;
+ } address;
+ struct sockaddr *sap = &address.sa;
socklen_t salen = sizeof(address);
struct pmap nfs_pmap, mnt_pmap;
+ sa_family_t family;
if (!nfs_options2pmap(options, &nfs_pmap, &mnt_pmap)) {
nfs_error(_("%s: bad mount options"), progname);
@@ -189,8 +194,10 @@ static int nfs_umount_do_umnt(struct mount_options *options,
return EX_FAIL;
}
- if (nfs_name_to_address(*hostname, sap, &salen) == 0)
- /* nfs_name_to_address reports any errors */
+ if (!nfs_mount_proto_family(options, &family))
+ return 0;
+ if (!nfs_lookup(*hostname, family, sap, &salen))
+ /* nfs_lookup reports any errors */
return EX_FAIL;
if (nfs_advise_umount(sap, salen, &mnt_pmap, dirname) == 0)
next prev parent reply other threads:[~2009-12-08 18:00 UTC|newest]
Thread overview: 12+ messages / expand[flat|nested] mbox.gz Atom feed top
2009-12-08 17:59 [PATCH 00/10] mount.nfs support for netids Chuck Lever
[not found] ` <20091208175128.2544.457.stgit-bi+AKbBUZKY6gyzm1THtWbp2dZbC/Bob@public.gmane.org>
2009-12-08 17:59 ` [PATCH 01/10] libnfs.a: Provide shared helpers for managing netids Chuck Lever
2009-12-08 17:59 ` [PATCH 02/10] mount.nfs: support netids in nfs_options2pmap() Chuck Lever
2009-12-08 17:59 ` [PATCH 03/10] mount.nfs: support netids in v2/v3 version/transport negotiation Chuck Lever
2009-12-08 17:59 ` [PATCH 04/10] mount.nfs: make nfs_lookup() global Chuck Lever
2009-12-08 18:00 ` [PATCH 05/10] mount.nfs: Add new API for getting protocol family from netids Chuck Lever
2009-12-08 18:00 ` [PATCH 06/10] mount.nfs: Fix sockaddr pointer aliasing in stropts.c Chuck Lever
2009-12-08 18:00 ` [PATCH 07/10] mount.nfs: proto=netid forces address family when resolving server names Chuck Lever
2009-12-08 18:00 ` Chuck Lever [this message]
2009-12-08 18:00 ` [PATCH 09/10] mount.nfs: Remove nfs_name_to_address() Chuck Lever
2009-12-08 18:00 ` [PATCH 10/10] NFS man page: update nfs(5) with details about IPv6 support Chuck Lever
2009-12-11 21:17 ` [PATCH 00/10] mount.nfs support for netids Steve Dickson
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20091208180033.2544.68238.stgit@localhost.localdomain \
--to=chuck.lever@oracle.com \
--cc=linux-nfs@vger.kernel.org \
--cc=steved@redhat.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox